//============================================================================
// 635 Linux Demonstration Code.
// test635,c: Ultra-simple 635 command-line communications example
// Copyright 2005, Crystalfontz America, Inc. Written by Brent A. Crosby
// www.crystalfontz.com, brent@crystalfontz.com
//============================================================================
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdlib.h>
#include "typedefs.h"
#include "serial.h"
#include "635_packet.h"
#include "show_packet.h"
#include "add_ons.h"
//============================================================================
int main(int argc, char* argv[])
  {
  //If only 0 or 1 parameter is entered, prompt for the missing parameter(s)
  if(argc < 3)
    {
      printf("\nMISSING A PARAMETER. Enter both PORT and BAUD.\n\n");
      return(0);
    }

  //Check for optional "clear" parameter and set flag if found
  int
    cleardisplay=0;
  if((argc > 3)&&(!strcmp(argv[3],"clear"))) cleardisplay=1;


  int
    baud;
  //default the baud to 115200
  if(strcmp(argv[2],"19200"))
    baud=115200;
  else
    baud=19200;

  if(Serial_Init(argv[1],baud))
    {
    printf("Could not open port \"%s\" at \"%d\" baud.\n",argv[1],baud);
    return(1);
    }
  else
    printf("\"%s\" opened at \"%d\" baud.\n\n",argv[1],baud);

  //For some reason, Linux seems to buffer up data from the LCD, and they are sometimes
  //dumped at the start of the program. Clear the serial buffer.
  while(BytesAvail())
    GetByte();

//Outgoing command packets. Either clear the screen
//or send our line information
//**********************************************
  if(cleardisplay)
  {
    clear_display();
  }
  else
  {
    //Clear display before doing anything
    clear_display();	

    char text_send[] = "type text string in here";
    send_character(0,0,'*'); //star is only displayed once and not updated
    scrolling_row(1,0,text_send);

    //CFA-635 communications protocol only allows
    //one outstanding packet at a time. Wait for the response
    //packet from the CFA-635 before sending another
    //packet.
    timeout_test();

    //Send line 2 to the 635 using command 31    
    //send_line(1,1,">>This is line 2<<",18);
    //timeout_test();
    
    //Send line 3 to the 635 using command 31
    //send_line(0,2,">>>This is line 3<<<",20);
    //timeout_test();
    
    //Send line 4 to the 635 using command 31
    //send_line(0,3,">>>This is line 4<<<",20);
    //timeout_test();
  }
//**********************************************

  printf("\nCtrl-C to exit.\n");
  printf("Updated display, now waiting for packets\n\n");

  while(!cleardisplay)
   {
     usleep(100000);  // 1/10 second
     if(check_for_packet())
       ShowReceivedPacket();
   }

  if(cleardisplay) printf("Display Cleared.\n");
  printf("Done.\n\n");
  Uninit_Serial();
  return 0;
  }
//============================================================================
